@@ -27,7 +27,7 @@ kApiLogin = '/userlogin/clilogin'
 kApiBusiness = '/console/client/cmd'
 kApiGlobal = '/index/client/cmd'
 
-gCliVersion = '0.2.14' # [2024/08/21 yilungao]
+gCliVersion = '0.2.15'
 
 gDicRegionToPrefix = {
     'dev': 'apgz',
@@ -161,6 +161,21 @@ gBundledCommands = [
     'import-title-data-json-content'
 ]
 
+def FillVerifyData(header = {}):
+    verify_type = GetConfig('verify-type')
+    if verify_type == "UserAccount":
+        header["CLIVerificationType"] = verify_type
+        user = GetConfig('portal-user')
+        psw = GetConfig('portal-pwd')
+        if len(user) == 0 or len(psw) == 0:
+            print('[portal-user] and [portal-pwd] must be set when [verify-type] is UserAccount')
+            os._exit(0)
+        header["CLIWebPortalUser"] = user
+        header["CLIWebPortalEncryptKey"] = psw
+    else:
+        header["CLIVerificationType"] = "SecretKey"
+    return header
+
 def MakeBusinessRequest(url, command, params):
     # use title region id firstly
     title_id = ""
@@ -171,8 +186,6 @@ def MakeBusinessRequest(url, command, params):
         title_id = GetConfig('title-id')
     title_region_id = GetConfig('title-region')
 
-    server_ticket = pgos_tools.GenerateServerTicket(title_region_id, GetConfig('secret-key'), title_id)
-
     # some commands need bundle the params to a sub key
     post_body_params = {}
     if command in gBundledCommands:
@@ -189,11 +202,18 @@ def MakeBusinessRequest(url, command, params):
     headers = {
         "Content-Type" : "application/json",
         "SecretID" : sever_key_array[0],
-        "ServerTicket" : server_ticket,
         "TitleID" : title_id,
         "TitleRegionID" : title_region_id
     }
-    
+
+    server_ticket = ""
+    if GetConfig('verify-type') != "UserAccount":
+        server_ticket = pgos_tools.GenerateServerTicket(title_region_id, GetConfig('secret-key'), title_id)
+        headers["ServerTicket"] = server_ticket
+        headers["CLIVerificationType"] = "SecretKey"
+    else:
+        FillVerifyData(headers)
+
     return pgos_tools.HttpPostWithHeaders(url, post_body, headers)
 
 def RequestCosSig(api, region, res_path, served_command_name, served_command_params:dict):
